@@ -49,7 +49,7 @@ def pylsp_settings():
 
 @hookimpl
 def pylsp_commands(config, workspace):
-    return [getattr(commands, cmd) for cmd in dir(commands) if not cmd.startswith('_')]
+    return [getattr(commands, cmd) for cmd in dir(commands) if not cmd.startswith("_")]
 
 
 @hookimpl
@@ -72,10 +72,12 @@ def pylsp_code_actions(config, workspace, document, range, context):
             "kind": "refactor.extract",
             "command": {
                 "command": commands.COMMAND_REFACTOR_EXTRACT_METHOD,
-                "arguments": {
-                    "document_uri": document.uri,
-                    "range": range,
-                },
+                "arguments": [
+                    {
+                        "document_uri": document.uri,
+                        "range": range,
+                    }
+                ],
             },
         }
     )
@@ -92,11 +94,13 @@ def pylsp_code_actions(config, workspace, document, range, context):
                 "kind": "refactor.extract",
                 "command": {
                     "command": commands.COMMAND_REFACTOR_EXTRACT_VARIABLE,
-                    "arguments": {
-                        "document_uri": document.uri,
-                        "range": range,
-                    },
-                }
+                    "arguments": [
+                        {
+                            "document_uri": document.uri,
+                            "range": range,
+                        }
+                    ],
+                },
             },
         )
 
@@ -108,8 +112,6 @@ def pylsp_code_actions(config, workspace, document, range, context):
         )
     except rope.base.exceptions.RefactoringError as e:
         pass
-    except rope.base.exceptions.RefactoringError as e:
-        logger.info("EEEHHHH",)
     else:
         code_actions.append(
             {
@@ -117,10 +119,12 @@ def pylsp_code_actions(config, workspace, document, range, context):
                 "kind": "refactor.inline",
                 "command": {
                     "command": commands.COMMAND_REFACTOR_INLINE,
-                    "arguments": {
-                        "document_uri": document.uri,
-                        "position": range["start"],
-                    },
+                    "arguments": [
+                        {
+                            "document_uri": document.uri,
+                            "position": range["start"],
+                        }
+                    ],
                 },
             },
         )
@@ -133,13 +137,13 @@ def pylsp_execute_command(config, workspace, command, arguments):
     logger.info("workspace/executeCommand: %s %s", command, arguments)
 
     if command == commands.COMMAND_REFACTOR_EXTRACT_METHOD:
-        refactor_extract_method(workspace, **arguments)
+        refactor_extract_method(workspace, **arguments[0])
 
     elif command == commands.COMMAND_REFACTOR_EXTRACT_VARIABLE:
-        refactor_extract_variable(workspace, **arguments)
+        refactor_extract_variable(workspace, **arguments[0])
 
     elif command == commands.COMMAND_REFACTOR_INLINE:
-        refactor_inline(workspace, **arguments)
+        refactor_inline(workspace, **arguments[0])
 
 
 def refactor_extract_method(workspace, document_uri, range):
