@@ -1,5 +1,7 @@
 from unittest.mock import ANY, call
 
+from test.conftest import read_fixture_file
+
 
 def assert_code_actions_do_not_offer(response, command):
     for action in response:
@@ -9,13 +11,13 @@ def assert_code_actions_do_not_offer(response, command):
 def assert_wholefile_changeset(document_changeset, target):
     assert len(document_changeset) == 1
     (change,) = document_changeset
-    new_text = open(target, "r").read()
+    new_text = read_fixture_file(target)
     assert change["newText"].strip() == new_text.strip()
     return new_text
 
 
 def assert_changeset(document_changeset, target):
-    new_text = open(target, "r").read()
+    new_text = read_fixture_file(target)
     for change in document_changeset:
         assert change["newText"] in new_text
     return new_text
