@@ -1,6 +1,5 @@
 from pylsp_rope import commands, plugin
 from pylsp_rope.text import Range
-from test.conftest import fixtures_dir
 from test.helpers import (
     assert_changeset,
     assert_code_actions_do_not_offer,
@@ -27,10 +26,12 @@ def test_extract_variable(config, workspace, document, code_action_context):
         "kind": "refactor.extract",
         "command": {
             "command": commands.COMMAND_REFACTOR_EXTRACT_VARIABLE,
-            "arguments": {
-                "document_uri": document.uri,
-                "range": selection,
-            },
+            "arguments": [
+                {
+                    "document_uri": document.uri,
+                    "range": selection,
+                }
+            ],
         },
     }
 
@@ -49,9 +50,7 @@ def test_extract_variable(config, workspace, document, code_action_context):
     edit_request = workspace._endpoint.request.call_args
 
     document_changeset = assert_single_document_edit(edit_request, document)
-    new_text = assert_changeset(
-        document_changeset, target=fixtures_dir / "simple_extract_variable.py"
-    )
+    new_text = assert_changeset(document_changeset, target="simple_extract_variable.py")
     assert "extracted_variable = " in new_text
 
 
@@ -93,10 +92,12 @@ def test_extract_method(config, workspace, document, code_action_context):
         "kind": "refactor.extract",
         "command": {
             "command": commands.COMMAND_REFACTOR_EXTRACT_METHOD,
-            "arguments": {
-                "document_uri": document.uri,
-                "range": selection,
-            },
+            "arguments": [
+                {
+                    "document_uri": document.uri,
+                    "range": selection,
+                }
+            ],
         },
     }
 
@@ -115,7 +116,5 @@ def test_extract_method(config, workspace, document, code_action_context):
     edit_request = workspace._endpoint.request.call_args
 
     document_changeset = assert_single_document_edit(edit_request, document)
-    new_text = assert_changeset(
-        document_changeset, target=fixtures_dir / "simple_extract_method.py"
-    )
+    new_text = assert_changeset(document_changeset, target="simple_extract_method.py")
     assert "def extracted_method(" in new_text
